==> pipewire-docs-1%3A0.3.33-1-armv6h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__keys.js <==
var group__spa__keys =
[
    [ "SPA_KEY_API_ALSA", "group__spa__keys.html#ga2a24032ac2675af80e58f291ed8f4010", null ],
    [ "SPA_KEY_API_ALSA_CARD", "group__spa__keys.html#gaace08681081c2fd86ec42ca2ac7d9a4e", null ],
    [ "SPA_KEY_API_ALSA_CARD_COMPONENTS", "group__spa__keys.html#ga397212748e5208c2727994b89ab56b04", null ],
    [ "SPA_KEY_API_ALSA_CARD_DRIVER", "group__spa__keys.html#gaa99aa65c64f6fb207cc7b567a59d759b", null ],
    [ "SPA_KEY_API_ALSA_CARD_ID", "group__spa__keys.html#gae257876566997855b6cc94aa12c60d85", null ],
    [ "SPA_KEY_API_ALSA_CARD_LONGNAME", "group__spa__keys.html#ga7a499235ee3ea2c06b0ea12d5f23754e", null ],
    [ "SPA_KEY_API_ALSA_CARD_MIXERNAME", "group__spa__keys.html#gaa82231588f7d2e0ce2231295b1c674b0", null ],
    [ "SPA_KEY_API_ALSA_CARD_NAME", "group__spa__keys.html#ga5fe280d124abe3a56346781116908033", null ],
    [ "SPA_KEY_API_ALSA_IGNORE_DB", "group__spa__keys.html#gad13b0f3fd7970f7bb1332782ff8d649e", null ],
    [ "SPA_KEY_API_ALSA_OPEN_UCM", "group__spa__keys.html#ga98db635729354c31033c8fe16fd28f00", null ],
    [ "SPA_KEY_API_ALSA_PATH", "group__spa__keys.html#gad11f51a8eaa7f2f2eea0074b5633f402", null ],
    [ "SPA_KEY_API_ALSA_PCM_CARD", "group__spa__keys.html#ga5e57673df39ef4db7003b489d450f34e", null ],
    [ "SPA_KEY_API_ALSA_PCM_CLASS", "group__spa__keys.html#ga303df0e437c81eecc7be8d7d6d7043fb", null ],
    [ "SPA_KEY_API_ALSA_PCM_DEVICE", "group__spa__keys.html#ga8810403864b34398fd00c697eb93c5eb", null ],
    [ "SPA_KEY_API_ALSA_PCM_ID", "group__spa__keys.html#ga50169e92dddfafd22153cb93f762215e", null ],
    [ "SPA_KEY_API_ALSA_PCM_NAME", "group__spa__keys.html#ga397bc03a68c5e52335662cc893114086", null ],
    [ "SPA_KEY_API_ALSA_PCM_STREAM", "group__spa__keys.html#ga79de2fae5c6d22458e004c53b52f7e71", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBCLASS", "group__spa__keys.html#ga7f2b56cc91fe175e3fe9a380c4784489", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBDEVICE", "group__spa__keys.html#ga6df017d9e8fb0a5e2ac9271693f1d3e2", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBNAME", "group__spa__keys.html#gae6934f93ea5aaa60d2136f0d9af5ad47", null ],
    [ "SPA_KEY_API_ALSA_PCM_SYNC_ID", "group__spa__keys.html#gaf4b04c9ed82a9d207ec02cea4d82de10", null ],
    [ "SPA_KEY_API_ALSA_USE_UCM", "group__spa__keys.html#gaad168538629a8a3be131de946dd83d68", null ],
    [ "SPA_KEY_API_BLUEZ5", "group__spa__keys.html#ga5bb3621f4d8a7ce7b6e4da99aa783c7a", null ],
    [ "SPA_KEY_API_BLUEZ5_ADDRESS", "group__spa__keys.html#ga39218bf95ccc444b5284386cf696a84b", null ],
    [ "SPA_KEY_API_BLUEZ5_CLASS", "group__spa__keys.html#ga3922fb11532f928abf055d8b9be5ec03", null ],
    [ "SPA_KEY_API_BLUEZ5_CODEC", "group__spa__keys.html#gae40f1dac2ce129ce24536b84f18464a6", null ],
    [ "SPA_KEY_API_BLUEZ5_CONNECTION", "group__spa__keys.html#ga8db98f0bdfb9b7c3b07dadf707c0d47b", null ],
    [ "SPA_KEY_API_BLUEZ5_DEVICE", "group__spa__keys.html#gaaf0e4a6e09ef95a5423174fedb697d85", null ],
    [ "SPA_KEY_API_BLUEZ5_ICON", "group__spa__keys.html#ga715d922eb1e490c97f4d8925ac4b8ebe", null ],
    [ "SPA_KEY_API_BLUEZ5_PATH", "group__spa__keys.html#ga1c7eb1e5cc136e4ae2f838b4ef84a705", null ],
    [ "SPA_KEY_API_BLUEZ5_PROFILE", "group__spa__keys.html#ga9a632331c39bbdd338abb7eecff159da", null ],
    [ "SPA_KEY_API_BLUEZ5_TRANSPORT", "group__spa__keys.html#ga48ef5b8474ebf455fc5784cd723ccb79", null ],
    [ "SPA_KEY_API_JACK", "group__spa__keys.html#ga7793a8ed3c5fb1376a56750470c24832", null ],
    [ "SPA_KEY_API_JACK_CLIENT", "group__spa__keys.html#gab4566b9446b8eb81b67632beb35f4612", null ],
    [ "SPA_KEY_API_JACK_SERVER", "group__spa__keys.html#ga4bf94a46ddb513183c1d2dff8bcbacda", null ],
    [ "SPA_KEY_API_LIBCAMERA", "group__spa__keys.html#gaba357c4725e9bed3857fbeb058cd4380", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_BUS_INFO", "group__spa__keys.html#ga49c1389221d9ad4088cb33f468ff8399", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_CAPABILITIES", "group__spa__keys.html#gabd502c2929edaae61182eb9f290334a4", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_CARD", "group__spa__keys.html#gad3ec15b6e5bbdd02f195a2356f2282de", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_DEVICE_CAPS", "group__spa__keys.html#ga93f7f32803291d2334ff345690f7bc27", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_DRIVER", "group__spa__keys.html#ga102acfa48ef947978f6dbd43198b40b8", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_VERSION", "group__spa__keys.html#ga24b3a715c206cc820fd7610668e3f674", null ],
    [ "SPA_KEY_API_LIBCAMERA_PATH", "group__spa__keys.html#ga5a5b6f28a0185f7c9740abfeb86a9f55", null ],
    [ "SPA_KEY_API_UDEV", "group__spa__keys.html#ga0dace91385a7adfa4181b957c5eb4b22", null ],
    [ "SPA_KEY_API_UDEV_MATCH", "group__spa__keys.html#gacbd114ae1cc6ad79d065292e645f8d44", null ],
    [ "SPA_KEY_API_V4L2", "group__spa__keys.html#ga3c297fc15190e6c2285ed1f4aa28fbe1", null ],
    [ "SPA_KEY_API_V4L2_CAP_BUS_INFO", "group__spa__keys.html#ga318114d113c9b8dc802d11bc1b012de9", null ],
    [ "SPA_KEY_API_V4L2_CAP_CAPABILITIES", "group__spa__keys.html#gabe022515f6ea717ba6248748fa286e68", null ],
    [ "SPA_KEY_API_V4L2_CAP_CARD", "group__spa__keys.html#gaa031c64e45e275af6cd9156dd8e4ec70", null ],
    [ "SPA_KEY_API_V4L2_CAP_DEVICE_CAPS", "group__spa__keys.html#gabc9ac8df508ea4562905c07457349443", null ],
    [ "SPA_KEY_API_V4L2_CAP_DRIVER", "group__spa__keys.html#ga72be7db883437eff091159091ed8ca4d", null ],
    [ "SPA_KEY_API_V4L2_CAP_VERSION", "group__spa__keys.html#ga14254eeea7166c2132dbaf78286ab1e3", null ],
    [ "SPA_KEY_API_V4L2_PATH", "group__spa__keys.html#gabaa741a54fc44d3850efd88e4feee291", null ],
    [ "SPA_KEY_MEDIA_CLASS", "group__spa__keys.html#ga3c5f231d55f3c9197139611ccd7a7222", null ],
    [ "SPA_KEY_MEDIA_ROLE", "group__spa__keys.html#ga4124c3a37af353a48f46b8a74d8fc450", null ],
    [ "SPA_KEY_OBJECT_PATH", "group__spa__keys.html#gaec49a8bf593696ff1aa0fc19d561d414", null ]
];

==> pipewire-docs-1%3A0.3.39-1-armv6h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__keys.js <==
var group__spa__keys =
[
    [ "keys.h", "spa_2include_2spa_2utils_2keys_8h.html", null ],
    [ "SPA_KEY_OBJECT_PATH", "group__spa__keys.html#gaec49a8bf593696ff1aa0fc19d561d414", null ],
    [ "SPA_KEY_MEDIA_CLASS", "group__spa__keys.html#ga3c5f231d55f3c9197139611ccd7a7222", null ],
    [ "SPA_KEY_MEDIA_ROLE", "group__spa__keys.html#ga4124c3a37af353a48f46b8a74d8fc450", null ],
    [ "SPA_KEY_API_UDEV", "group__spa__keys.html#ga0dace91385a7adfa4181b957c5eb4b22", null ],
    [ "SPA_KEY_API_UDEV_MATCH", "group__spa__keys.html#gacbd114ae1cc6ad79d065292e645f8d44", null ],
    [ "SPA_KEY_API_ALSA", "group__spa__keys.html#ga2a24032ac2675af80e58f291ed8f4010", null ],
    [ "SPA_KEY_API_ALSA_PATH", "group__spa__keys.html#gad11f51a8eaa7f2f2eea0074b5633f402", null ],
    [ "SPA_KEY_API_ALSA_CARD", "group__spa__keys.html#gaace08681081c2fd86ec42ca2ac7d9a4e", null ],
    [ "SPA_KEY_API_ALSA_USE_UCM", "group__spa__keys.html#gaad168538629a8a3be131de946dd83d68", null ],
    [ "SPA_KEY_API_ALSA_IGNORE_DB", "group__spa__keys.html#gad13b0f3fd7970f7bb1332782ff8d649e", null ],
    [ "SPA_KEY_API_ALSA_OPEN_UCM", "group__spa__keys.html#ga98db635729354c31033c8fe16fd28f00", null ],
    [ "SPA_KEY_API_ALSA_CARD_ID", "group__spa__keys.html#gae257876566997855b6cc94aa12c60d85", null ],
    [ "SPA_KEY_API_ALSA_CARD_COMPONENTS", "group__spa__keys.html#ga397212748e5208c2727994b89ab56b04", null ],
    [ "SPA_KEY_API_ALSA_CARD_DRIVER", "group__spa__keys.html#gaa99aa65c64f6fb207cc7b567a59d759b", null ],
    [ "SPA_KEY_API_ALSA_CARD_NAME", "group__spa__keys.html#ga5fe280d124abe3a56346781116908033", null ],
    [ "SPA_KEY_API_ALSA_CARD_LONGNAME", "group__spa__keys.html#ga7a499235ee3ea2c06b0ea12d5f23754e", null ],
    [ "SPA_KEY_API_ALSA_CARD_MIXERNAME", "group__spa__keys.html#gaa82231588f7d2e0ce2231295b1c674b0", null ],
    [ "SPA_KEY_API_ALSA_PCM_ID", "group__spa__keys.html#ga50169e92dddfafd22153cb93f762215e", null ],
    [ "SPA_KEY_API_ALSA_PCM_CARD", "group__spa__keys.html#ga5e57673df39ef4db7003b489d450f34e", null ],
    [ "SPA_KEY_API_ALSA_PCM_NAME", "group__spa__keys.html#ga397bc03a68c5e52335662cc893114086", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBNAME", "group__spa__keys.html#gae6934f93ea5aaa60d2136f0d9af5ad47", null ],
    [ "SPA_KEY_API_ALSA_PCM_STREAM", "group__spa__keys.html#ga79de2fae5c6d22458e004c53b52f7e71", null ],
    [ "SPA_KEY_API_ALSA_PCM_CLASS", "group__spa__keys.html#ga303df0e437c81eecc7be8d7d6d7043fb", null ],
    [ "SPA_KEY_API_ALSA_PCM_DEVICE", "group__spa__keys.html#ga8810403864b34398fd00c697eb93c5eb", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBDEVICE", "group__spa__keys.html#ga6df017d9e8fb0a5e2ac9271693f1d3e2", null ],
    [ "SPA_KEY_API_ALSA_PCM_SUBCLASS", "group__spa__keys.html#ga7f2b56cc91fe175e3fe9a380c4784489", null ],
    [ "SPA_KEY_API_ALSA_PCM_SYNC_ID", "group__spa__keys.html#gaf4b04c9ed82a9d207ec02cea4d82de10", null ],
    [ "SPA_KEY_API_V4L2", "group__spa__keys.html#ga3c297fc15190e6c2285ed1f4aa28fbe1", null ],
    [ "SPA_KEY_API_V4L2_PATH", "group__spa__keys.html#gabaa741a54fc44d3850efd88e4feee291", null ],
    [ "SPA_KEY_API_LIBCAMERA", "group__spa__keys.html#gaba357c4725e9bed3857fbeb058cd4380", null ],
    [ "SPA_KEY_API_LIBCAMERA_PATH", "group__spa__keys.html#ga5a5b6f28a0185f7c9740abfeb86a9f55", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_DRIVER", "group__spa__keys.html#ga102acfa48ef947978f6dbd43198b40b8", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_CARD", "group__spa__keys.html#gad3ec15b6e5bbdd02f195a2356f2282de", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_BUS_INFO", "group__spa__keys.html#ga49c1389221d9ad4088cb33f468ff8399", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_VERSION", "group__spa__keys.html#ga24b3a715c206cc820fd7610668e3f674", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_CAPABILITIES", "group__spa__keys.html#gabd502c2929edaae61182eb9f290334a4", null ],
    [ "SPA_KEY_API_LIBCAMERA_CAP_DEVICE_CAPS", "group__spa__keys.html#ga93f7f32803291d2334ff345690f7bc27", null ],
    [ "SPA_KEY_API_V4L2_CAP_DRIVER", "group__spa__keys.html#ga72be7db883437eff091159091ed8ca4d", null ],
    [ "SPA_KEY_API_V4L2_CAP_CARD", "group__spa__keys.html#gaa031c64e45e275af6cd9156dd8e4ec70", null ],
    [ "SPA_KEY_API_V4L2_CAP_BUS_INFO", "group__spa__keys.html#ga318114d113c9b8dc802d11bc1b012de9", null ],
    [ "SPA_KEY_API_V4L2_CAP_VERSION", "group__spa__keys.html#ga14254eeea7166c2132dbaf78286ab1e3", null ],
    [ "SPA_KEY_API_V4L2_CAP_CAPABILITIES", "group__spa__keys.html#gabe022515f6ea717ba6248748fa286e68", null ],
    [ "SPA_KEY_API_V4L2_CAP_DEVICE_CAPS", "group__spa__keys.html#gabc9ac8df508ea4562905c07457349443", null ],
    [ "SPA_KEY_API_BLUEZ5", "group__spa__keys.html#ga5bb3621f4d8a7ce7b6e4da99aa783c7a", null ],
    [ "SPA_KEY_API_BLUEZ5_PATH", "group__spa__keys.html#ga1c7eb1e5cc136e4ae2f838b4ef84a705", null ],
    [ "SPA_KEY_API_BLUEZ5_DEVICE", "group__spa__keys.html#gaaf0e4a6e09ef95a5423174fedb697d85", null ],
    [ "SPA_KEY_API_BLUEZ5_CONNECTION", "group__spa__keys.html#ga8db98f0bdfb9b7c3b07dadf707c0d47b", null ],
    [ "SPA_KEY_API_BLUEZ5_TRANSPORT", "group__spa__keys.html#ga48ef5b8474ebf455fc5784cd723ccb79", null ],
    [ "SPA_KEY_API_BLUEZ5_PROFILE", "group__spa__keys.html#ga9a632331c39bbdd338abb7eecff159da", null ],
    [ "SPA_KEY_API_BLUEZ5_ADDRESS", "group__spa__keys.html#ga39218bf95ccc444b5284386cf696a84b", null ],
    [ "SPA_KEY_API_BLUEZ5_CODEC", "group__spa__keys.html#gae40f1dac2ce129ce24536b84f18464a6", null ],
    [ "SPA_KEY_API_BLUEZ5_CLASS", "group__spa__keys.html#ga3922fb11532f928abf055d8b9be5ec03", null ],
    [ "SPA_KEY_API_BLUEZ5_ICON", "group__spa__keys.html#ga715d922eb1e490c97f4d8925ac4b8ebe", null ],
    [ "SPA_KEY_API_JACK", "group__spa__keys.html#ga7793a8ed3c5fb1376a56750470c24832", null ],
    [ "SPA_KEY_API_JACK_SERVER", "group__spa__keys.html#ga4bf94a46ddb513183c1d2dff8bcbacda", null ],
    [ "SPA_KEY_API_JACK_CLIENT", "group__spa__keys.html#gab4566b9446b8eb81b67632beb35f4612", null ]
];
